@@ -1,9 +1,6 @@
-"""Top-level janitor API lives here.
-
-Lazy loading used here to speed up imports.
-"""
-import lazy_loader as lazy
+"""Top-level janitor API lives here."""
 
+import pandas_flavor as pf  # noqa: F401
 
 from .accessors import *  # noqa: F403, F401
 from .functions import *  # noqa: F403, F401
@@ -11,14 +8,7 @@ from .io import *  # noqa: F403, F401
 from .math import *  # noqa: F403, F401
 from .ml import get_features_targets as _get_features_targets
 from .utils import refactored_function
-
-
-_ = lazy.load("pandas_flavor")
-
-try:
-    jxr = lazy.load("janitor.xarray")  # noqa: F401
-except ImportError:
-    pass
+from .xarray import *  # noqa: F403, F401
 
 
 @refactored_function(
@@ -29,4 +19,4 @@ def get_features_targets(*args, **kwargs):
     return _get_features_targets(*args, **kwargs)
 
 
-__version__ = "0.24.0"
+__version__ = "0.29.2"
