@@ -1,8 +1,9 @@
-import lazy_loader as lazy
+"""DataDescription class for the DataDescription accessor."""
+
 from typing import Dict, List, Union
 
-pf = lazy.load("pandas_flavor")
-pd = lazy.load("pandas")
+import pandas as pd
+import pandas_flavor as pf
 
 
 @pf.register_dataframe_accessor("data_description")
@@ -13,11 +14,14 @@ class DataDescription:
     """
 
     def __init__(self, data):
-        """Initialize DataDescription class."""
         self._data = data
         self._desc = {}
 
     def _get_data_df(self) -> pd.DataFrame:
+        """Get a table of descriptive information in a DataFrame format.
+
+        :returns: A DataFrame containing the descriptive information.
+        """
         df = self._data
 
         data_dict = {}
@@ -45,9 +49,12 @@ class DataDescription:
     def set_description(self, desc: Union[List, Dict]):
         """Update the description for each of the columns in the DataFrame.
 
-        :param desc: The structure containing the descriptions to update
-        :raises ValueError: if length of description list does not match
-            number of columns in DataFrame.
+        Args:
+            desc: The structure containing the descriptions to update
+
+        Raises:
+            ValueError: If length of description list does not match
+                number of columns in DataFrame.
         """
         if isinstance(desc, list):
             if len(desc) != len(self._data.columns):
