@@ -1,15 +1,14 @@
 """Implementation of drop_constant_columns."""
-import pandas_flavor as pf
+
 import pandas as pd
+import pandas_flavor as pf
 
 
 @pf.register_dataframe_method
 def drop_constant_columns(df: pd.DataFrame) -> pd.DataFrame:
-    """
-    Finds and drops the constant columns from a Pandas DataFrame.
-
-    Example:
+    """Finds and drops the constant columns from a Pandas DataFrame.
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> data_dict = {
@@ -31,14 +30,10 @@ def drop_constant_columns(df: pd.DataFrame) -> pd.DataFrame:
         1  2  leopard   Shanghai
         2  3     lion      Basel
 
-    :param df: Input Pandas DataFrame
-    :returns: The Pandas DataFrame with the constant columns dropped.
-    """
-    # Find the constant columns
-    constant_columns = []
-    for col in df.columns:
-        if len(df[col].unique()) == 1:
-            constant_columns.append(col)
+    Args:
+        df: Input Pandas DataFrame
 
-    # Drop constant columns from df and return it
-    return df.drop(labels=constant_columns, axis=1)
+    Returns:
+        The Pandas DataFrame with the constant columns dropped.
+    """
+    return df.loc[:, df.nunique().ne(1)]
