@@ -1,12 +1,21 @@
-from typing import Callable, List, Union
-import pandas_flavor as pf
-import pandas as pd
+"""Implementation source for `groupby_agg`."""
 
-from janitor.utils import deprecated_alias
+from typing import Callable, List, Union
+
+import pandas as pd
+import pandas_flavor as pf
+
+from janitor.utils import deprecated_alias, refactored_function
 
 
 @pf.register_dataframe_method
 @deprecated_alias(new_column="new_column_name", agg_column="agg_column_name")
+@refactored_function(
+    message=(
+        "This function will be deprecated in a 1.x release. "
+        "Please use `janitor.transform_column` instead."
+    )
+)
 def groupby_agg(
     df: pd.DataFrame,
     by: Union[List, Callable, str],
@@ -25,7 +34,15 @@ def groupby_agg(
     df = df.assign(...=df.groupby(...)[...].transform(...))
     ```
 
-    Example: Basic usage.
+    !!!note
+
+        This function will be deprecated in a 1.x release.
+        Please use
+        [`jn.transform_column`][janitor.functions.transform_columns.transform_column]
+        instead.
+
+    Examples:
+        Basic usage.
 
         >>> import pandas as pd
         >>> import janitor
@@ -46,8 +63,8 @@ def groupby_agg(
         3  shoe       200         140.0
         4   bag        25          50.0
 
-    Example: Set `dropna=False` to compute the aggregation, treating the null
-    values in the `by` column as an isolated "group".
+        Set `dropna=False` to compute the aggregation, treating the null
+        values in the `by` column as an isolated "group".
 
         >>> import pandas as pd
         >>> import janitor
@@ -67,15 +84,18 @@ def groupby_agg(
         2  None  9        1
         3     b  9        1
 
-    :param df: A pandas DataFrame.
-    :param by: Column(s) to groupby on, will be passed into `DataFrame.groupby`.
-    :param new_column_name: Name of the aggregation output column.
-    :param agg_column_name: Name of the column to aggregate over.
-    :param agg: How to aggregate.
-    :param dropna: Whether or not to include null values, if present in the
-        `by` column(s). Default is True (null values in `by` are assigned NaN in
-        the new column).
-    :returns: A pandas DataFrame.
+    Args:
+        df: A pandas DataFrame.
+        by: Column(s) to groupby on, will be passed into `DataFrame.groupby`.
+        new_column_name: Name of the aggregation output column.
+        agg_column_name: Name of the column to aggregate over.
+        agg: How to aggregate.
+        dropna: Whether or not to include null values, if present in the
+            `by` column(s). Default is True (null values in `by` are assigned NaN in
+            the new column).
+
+    Returns:
+        A pandas DataFrame.
     """  # noqa: E501
 
     return df.assign(
