@@ -1,20 +1,34 @@
-import inspect
-import pandas_flavor as pf
-import pandas as pd
+"""Implementation source for `process_text`."""
 
-from janitor.utils import check, check_column, deprecated_alias
+import inspect
+from typing import Any
+
+import pandas as pd
+import pandas_flavor as pf
+
+from janitor.utils import (
+    check,
+    check_column,
+    deprecated_alias,
+    refactored_function,
+)
 
 
 @pf.register_dataframe_method
+@refactored_function(
+    message=(
+        "This function will be deprecated in a 1.x release. "
+        "Please use `jn.transform_columns` instead."
+    )
+)
 @deprecated_alias(column="column_name")
 def process_text(
     df: pd.DataFrame,
     column_name: str,
     string_function: str,
-    **kwargs,
+    **kwargs: Any,
 ) -> pd.DataFrame:
-    """
-    Apply a Pandas string method to an existing column.
+    """Apply a Pandas string method to an existing column.
 
     This function aims to make string cleaning easy, while chaining,
     by simply passing the string method name,
@@ -24,12 +38,15 @@ def process_text(
     new columns can be created via pyjanitor's
     [`transform_columns`][janitor.functions.transform_columns.transform_columns].
 
-
     A list of all the string methods in Pandas can be accessed [here](https://pandas.pydata.org/docs/user_guide/text.html#method-summary).
 
+    !!!note
 
-    Example:
+        This function will be deprecated in a 1.x release.
+        Please use [`jn.transform_column`][janitor.functions.transform_columns.transform_column]
+        instead.
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> import re
@@ -46,7 +63,7 @@ def process_text(
         1  sammywemmy     2
         2      ginger     3
 
-    For string methods with parameters, simply pass the keyword arguments:
+        For string methods with parameters, simply pass the keyword arguments:
 
         >>> df.process_text(
         ...     column_name="text",
@@ -60,13 +77,18 @@ def process_text(
         1  NaN     2
         2  NaN     3
 
-    :param df: A pandas DataFrame.
-    :param column_name: String column to be operated on.
-    :param string_function: pandas string method to be applied.
-    :param kwargs: Keyword arguments for parameters of the `string_function`.
-    :returns: A pandas DataFrame with modified column.
-    :raises KeyError: If `string_function` is not a Pandas string method.
-    :raises ValueError: If the text function returns a DataFrame, instead of a Series.
+    Args:
+        df: A pandas DataFrame.
+        column_name: String column to be operated on.
+        string_function: pandas string method to be applied.
+        **kwargs: Keyword arguments for parameters of the `string_function`.
+
+    Raises:
+        KeyError: If `string_function` is not a Pandas string method.
+        ValueError: If the text function returns a DataFrame, instead of a Series.
+
+    Returns:
+        A pandas DataFrame with modified column.
     """  # noqa: E501
 
     check("column_name", column_name, [str])
