@@ -1,23 +1,20 @@
 """Implementation of remove_empty."""
-import pandas_flavor as pf
+
 import pandas as pd
+import pandas_flavor as pf
 
 
 @pf.register_dataframe_method
-def remove_empty(df: pd.DataFrame) -> pd.DataFrame:
+def remove_empty(df: pd.DataFrame, reset_index: bool = True) -> pd.DataFrame:
     """Drop all rows and columns that are completely null.
 
-    This method also resets the index (by default) since it doesn't make sense
-    to preserve the index of a completely empty row.
-
-    This method mutates the original DataFrame.
+    This method does not mutate the original DataFrame.
 
     Implementation is inspired from [StackOverflow][so].
 
     [so]: https://stackoverflow.com/questions/38884538/python-pandas-find-all-rows-where-all-values-are-nan
 
-    Example:
-
+    Examples:
         >>> import numpy as np
         >>> import pandas as pd
         >>> import janitor
@@ -36,13 +33,15 @@ def remove_empty(df: pd.DataFrame) -> pd.DataFrame:
         0  1.0  3.0
         1  2.0  4.0
 
-    :param df: The pandas DataFrame object.
-    :returns: A pandas DataFrame.
+    Args:
+        df: The pandas DataFrame object.
+        reset_index: Determines if the index is reset.
+
+    Returns:
+        A pandas DataFrame.
     """  # noqa: E501
-    nanrows = df.index[df.isna().all(axis=1)]
-    df = df.drop(index=nanrows).reset_index(drop=True)
-
-    nancols = df.columns[df.isna().all(axis=0)]
-    df = df.drop(columns=nancols)
-
-    return df
+    outcome = df.isna()
+    outcome = df.loc[~outcome.all(axis=1), ~outcome.all(axis=0)]
+    if reset_index:
+        return outcome.reset_index(drop=True)
+    return outcome
