@@ -1,11 +1,14 @@
 """Implementation of `shuffle` functions."""
-import pandas_flavor as pf
+
+from typing import Any
+
 import pandas as pd
+import pandas_flavor as pf
 
 
 @pf.register_dataframe_method
 def shuffle(
-    df: pd.DataFrame, random_state=None, reset_index: bool = True
+    df: pd.DataFrame, random_state: Any = None, reset_index: bool = True
 ) -> pd.DataFrame:
     """Shuffle the rows of the DataFrame.
 
@@ -14,8 +17,7 @@ def shuffle(
     Super-sugary syntax! Underneath the hood, we use `df.sample(frac=1)`,
     with the option to set the random state.
 
-    Example:
-
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> df = pd.DataFrame({
@@ -37,12 +39,15 @@ def shuffle(
         3     0    a
         4     3    d
 
-    :param df: A pandas DataFrame.
-    :param random_state: If provided, set a seed for the random number
-        generator.
-    :param reset_index: If True, reset the dataframe index to the default
-        RangeIndex.
-    :returns: A shuffled pandas DataFrame.
+    Args:
+        df: A pandas DataFrame.
+        random_state: If provided, set a seed for the random number
+            generator. Passed to `pd.DataFrame.sample()`.
+        reset_index: If True, reset the dataframe index to the default
+            RangeIndex.
+
+    Returns:
+        A shuffled pandas DataFrame.
     """
     result = df.sample(frac=1, random_state=random_state)
     if reset_index:
