@@ -1,20 +1,22 @@
 """Implementation of the `sort_column_value_order` function."""
-import pandas_flavor as pf
+
 import pandas as pd
+import pandas_flavor as pf
+
 from janitor.utils import check, check_column
-from .remove_columns import remove_columns  # noqa: F401
 
 
 @pf.register_dataframe_method
 def sort_column_value_order(
-    df: pd.DataFrame, column: str, column_value_order: dict, columns=None
+    df: pd.DataFrame,
+    column: str,
+    column_value_order: dict,
+    columns: str = None,
 ) -> pd.DataFrame:
-    """
-    This function adds precedence to certain values in a specified column, then
-    sorts based on that column and any other specified columns.
-
-    Example:
+    """This function adds precedence to certain values in a specified column,
+    then sorts based on that column and any other specified columns.
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> import numpy as np
@@ -43,15 +45,20 @@ def sort_column_value_order(
         2        Feb     200.0     250.0     500.0
         0        Jan     150.0     180.0     400.0
 
-    :param df: This is our DataFrame that we are manipulating
-    :param column: This is a column name as a string we are using to specify
-        which column to sort by
-    :param column_value_order: This is a dictionary of values that will
-        represent precedence of the values in the specified column
-    :param columns: This is a list of additional columns that we can sort by
-    :raises ValueError: raises error if chosen Column Name is not in
-        Dataframe, or if column_value_order dictionary is empty.
-    :return: A sorted pandas DataFrame.
+    Args:
+        df: pandas DataFrame that we are manipulating
+        column: This is a column name as a string we are using to specify
+            which column to sort by
+        column_value_order: Dictionary of values that will
+            represent precedence of the values in the specified column
+        columns: A list of additional columns that we can sort by
+
+    Raises:
+        ValueError: If chosen Column Name is not in
+            Dataframe, or if `column_value_order` dictionary is empty.
+
+    Returns:
+        A sorted pandas DataFrame.
     """
     # Validation checks
     check_column(df, column, present=True)
@@ -59,7 +66,7 @@ def sort_column_value_order(
     if not column_value_order:
         raise ValueError("column_value_order dictionary cannot be empty")
 
-    df = df.assign(cond_order=df[column].replace(column_value_order))
+    df = df.assign(cond_order=df[column].map(column_value_order))
 
     sort_by = ["cond_order"]
     if columns is not None:
