@@ -1,7 +1,9 @@
 """Implementation of take_first function."""
+
 from typing import Hashable, Iterable, Union
-import pandas_flavor as pf
+
 import pandas as pd
+import pandas_flavor as pf
 
 
 @pf.register_dataframe_method
@@ -11,11 +13,9 @@ def take_first(
     by: Hashable,
     ascending: bool = True,
 ) -> pd.DataFrame:
-    """
-    Take the first row within each group specified by `subset`.
-
-    Example:
+    """Take the first row within each group specified by `subset`.
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> df = pd.DataFrame({"a": ["x", "x", "y", "y"], "b": [0, 1, 2, 3]})
@@ -30,11 +30,14 @@ def take_first(
         0  x  0
         2  y  2
 
-    :param df: A pandas DataFrame.
-    :param subset: Column(s) defining the group.
-    :param by: Column to sort by.
-    :param ascending: Whether or not to sort in ascending order, `bool`.
-    :returns: A pandas DataFrame.
+    Args:
+        df: A pandas DataFrame.
+        subset: Column(s) defining the group.
+        by: Column to sort by.
+        ascending: Whether or not to sort in ascending order, `bool`.
+
+    Returns:
+        A pandas DataFrame.
     """
     result = df.sort_values(by=by, ascending=ascending).drop_duplicates(
         subset=subset, keep="first"
