@@ -1,24 +1,42 @@
-from typing import Hashable
-import pandas_flavor as pf
-import pandas as pd
+"""Implementation source for `to_datetime`."""
 
-from janitor.utils import deprecated_alias
+from typing import Any, Hashable
+
+import pandas as pd
+import pandas_flavor as pf
+
+from janitor.utils import deprecated_alias, refactored_function
 
 
 @pf.register_dataframe_method
 @deprecated_alias(column="column_name")
+@refactored_function(
+    message=(
+        "This function will be deprecated in a 1.x release. "
+        "Please use `jn.transform_columns` instead."
+    )
+)
 def to_datetime(
-    df: pd.DataFrame, column_name: Hashable, **kwargs
+    df: pd.DataFrame, column_name: Hashable, **kwargs: Any
 ) -> pd.DataFrame:
     """Convert column to a datetime type, in-place.
 
     Intended to be the method-chaining equivalent of:
 
-        df[column_name] = pd.to_datetime(df[column_name], **kwargs)
+    ```python
+    df[column_name] = pd.to_datetime(df[column_name], **kwargs)
+    ```
 
     This method mutates the original DataFrame.
 
-    Example: Converting a string column to datetime type with custom format.
+    !!!note
+
+        This function will be deprecated in a 1.x release.
+        Please use [`jn.transform_column`][janitor.functions.transform_columns.transform_column]
+        instead.
+
+    Examples:
+        Converting a string column to datetime type with custom format.
 
         >>> import pandas as pd
         >>> import janitor
@@ -38,10 +56,13 @@ def to_datetime(
 
     [pd_docs]: https://pandas.pydata.org/docs/reference/api/pandas.to_datetime.html
 
-    :param df: A pandas DataFrame.
-    :param column_name: Column name.
-    :param kwargs: Provide any kwargs that `pd.to_datetime` can take.
-    :returns: A pandas DataFrame with updated datetime data.
+    Args:
+        df: A pandas DataFrame.
+        column_name: Column name.
+        **kwargs: Provide any kwargs that `pd.to_datetime` can take.
+
+    Returns:
+        A pandas DataFrame with updated datetime data.
     """  # noqa: E501
     df[column_name] = pd.to_datetime(df[column_name], **kwargs)
 
