@@ -1,42 +1,57 @@
 from __future__ import annotations
+
+import inspect
 import os
 import subprocess
+import warnings
+from collections import defaultdict
 from glob import glob
 from io import StringIO
-from typing import Iterable, Union, TYPE_CHECKING, NamedTuple
-
+from itertools import chain
+from typing import IO, TYPE_CHECKING, Any, Iterable, Mapping, Union
 
 import pandas as pd
-import inspect
+
+from janitor.utils import (
+    check,
+    deprecated_alias,
+    find_stack_level,
+    import_message,
+)
 
 from .errors import JanitorError
-from .utils import deprecated_alias, check, import_message
-from collections import defaultdict
-from itertools import chain
+
+warnings.simplefilter("always", DeprecationWarning)
 
 
 @deprecated_alias(seperate_df="separate_df", filespath="files_path")
 def read_csvs(
-    files_path: Union[str, Iterable[str]], separate_df: bool = False, **kwargs
+    files_path: Union[str, Iterable[str]],
+    separate_df: bool = False,
+    **kwargs: Any,
 ) -> Union[pd.DataFrame, dict]:
-    """
-    Read multiple CSV files and return a dictionary of DataFrames, or
+    """Read multiple CSV files and return a dictionary of DataFrames, or
     one concatenated DataFrame.
 
-    :param files_path: The filepath pattern matching the CSV files.
-        Accepts regular expressions, with or without `.csv` extension.
-        Also accepts iterable of file paths.
-    :param separate_df: If `False` (default), returns a single Dataframe
-        with the concatenation of the csv files.
-        If `True`, returns a dictionary of separate DataFrames
-        for each CSV file.
-    :param kwargs: Keyword arguments to pass into the
-        original pandas `read_csv`.
-    :returns: DataFrame of concatenated DataFrames or dictionary of DataFrames.
-    :raises JanitorError: if `None` provided for `files_path`.
-    :raises JanitorError: if length of `files_path` is `0`.
-    :raises ValueError: if no CSV files exist in `files_path`.
-    :raises ValueError: if columns in input CSV files do not match.
+    Args:
+        files_path: The filepath pattern matching the CSV files.
+            Accepts regular expressions, with or without `.csv` extension.
+            Also accepts iterable of file paths.
+        separate_df: If `False` (default), returns a single Dataframe
+            with the concatenation of the csv files.
+            If `True`, returns a dictionary of separate DataFrames
+            for each CSV file.
+        **kwargs: Keyword arguments to pass into the
+            original pandas `read_csv`.
+
+    Raises:
+        JanitorError: If `None` provided for `files_path`.
+        JanitorError: If length of `files_path` is `0`.
+        ValueError: If no CSV files exist in `files_path`.
+        ValueError: If columns in input CSV files do not match.
+
+    Returns:
+        DataFrame of concatenated DataFrames or dictionary of DataFrames.
     """
     # Sanitize input
     if files_path is None:
@@ -78,9 +93,10 @@ def read_csvs(
     return dfs_dict
 
 
-def read_commandline(cmd: str, **kwargs) -> pd.DataFrame:
-    """
-    Read a CSV file based on a command-line command.
+def read_commandline(
+    cmd: str, engine: str = "pandas", **kwargs: Any
+) -> Mapping:
+    """Read a CSV file based on a command-line command.
 
     For example, you may wish to run the following command on `sep-quarter.csv`
     before reading it into a pandas DataFrame:
@@ -97,23 +113,42 @@ def read_commandline(cmd: str, **kwargs) -> pd.DataFrame:
     ```
 
     This function assumes that your command line command will return
-    an output that is parsable using `pandas.read_csv` and StringIO.
-    We default to using `pd.read_csv` underneath the hood.
-    Keyword arguments are passed through to read_csv.
+    an output that is parsable using the relevant engine and StringIO.
+    This function defaults to using `pd.read_csv` underneath the hood.
+    Keyword arguments are passed through as-is.
 
-    :param cmd: Shell command to preprocess a file on disk.
-    :param kwargs: Keyword arguments that are passed through to
-        `pd.read_csv()`.
-    :returns: A pandas DataFrame parsed from the stdout of the underlying
-        shell.
+    Args:
+        cmd: Shell command to preprocess a file on disk.
+        engine: DataFrame engine to process the output of the shell command.
+            Currently supports both pandas and polars.
+        **kwargs: Keyword arguments that are passed through to
+            the engine's csv reader.
+
+
+    Returns:
+        A DataFrame parsed from the stdout of the underlying
+            shell.
     """
 
     check("cmd", cmd, [str])
+    if engine not in {"pandas", "polars"}:
+        raise ValueError("engine should be either pandas or polars.")
     # adding check=True ensures that an explicit, clear error
     # is raised, so that the user can see the reason for the failure
     outcome = subprocess.run(
         cmd, shell=True, capture_output=True, text=True, check=True
     )
+    if engine == "polars":
+        try:
+            import polars as pl
+        except ImportError:
+            import_message(
+                submodule="polars",
+                package="polars",
+                conda_channel="conda-forge",
+                pip_install=True,
+            )
+        return pl.read_csv(StringIO(outcome.stdout), **kwargs)
     return pd.read_csv(StringIO(outcome.stdout), **kwargs)
 
 
@@ -122,30 +157,32 @@ if TYPE_CHECKING:
 
 
 def xlsx_table(
-    path: Union[str, Workbook],
-    sheetname: str,
+    path: Union[str, IO, Workbook],
+    sheetname: str = None,
     table: Union[str, list, tuple] = None,
-) -> Union[pd.DataFrame, dict]:
-    """
-    Returns a DataFrame of values in a table in the Excel file.
+    engine: str = "pandas",
+) -> Mapping:
+    """Returns a DataFrame of values in a table in the Excel file.
+
     This applies to an Excel file, where the data range is explicitly
     specified as a Microsoft Excel table.
 
     If there is a single table in the sheet, or a string is provided
-    as an argument to the `table` parameter, a pandas DataFrame is returned;
+    as an argument to the `table` parameter, a DataFrame is returned;
     if there is more than one table in the sheet,
     and the `table` argument is `None`, or a list/tuple of names,
     a dictionary of DataFrames is returned, where the keys of the dictionary
     are the table names.
 
-    Example:
-
+    Examples:
         >>> import pandas as pd
+        >>> import polars as pl
         >>> from janitor import xlsx_table
         >>> filename="../pyjanitor/tests/test_data/016-MSPTDA-Excel.xlsx"
 
-        # single table
-        >>> xlsx_table(filename, sheetname='Tables', table='dCategory')
+        Single table:
+
+        >>> xlsx_table(filename, table='dCategory')
            CategoryID       Category
         0           1       Beginner
         1           2       Advanced
@@ -153,8 +190,23 @@ def xlsx_table(
         3           4    Competition
         4           5  Long Distance
 
-        # multiple tables:
-        >>> out=xlsx_table(filename, sheetname="Tables", table=["dCategory", "dSalesReps"])
+        >>> xlsx_table(filename, table='dCategory', engine='polars')
+        shape: (5, 2)
+        ┌────────────┬───────────────┐
+        │ CategoryID ┆ Category      │
+        │ ---        ┆ ---           │
+        │ i64        ┆ str           │
+        ╞════════════╪═══════════════╡
+        │ 1          ┆ Beginner      │
+        │ 2          ┆ Advanced      │
+        │ 3          ┆ Freestyle     │
+        │ 4          ┆ Competition   │
+        │ 5          ┆ Long Distance │
+        └────────────┴───────────────┘
+
+        Multiple tables:
+
+        >>> out=xlsx_table(filename, table=["dCategory", "dSalesReps"])
         >>> out["dCategory"]
            CategoryID       Category
         0           1       Beginner
@@ -168,18 +220,21 @@ def xlsx_table(
         1           2        Tyrone Smithe     NE
         2           3         Chantel Zoya     SW
 
-    :param path: Path to the Excel File. It can also be an openpyxl Workbook.
-    :param sheetname: Name of the sheet from which the tables
-        are to be extracted.
-    :param table: Name of a table, or list of tables in the sheet.
-    :returns: A pandas DataFrame, or a dictionary of DataFrames,
-        if there are multiple arguments for the `table` parameter,
-        or the argument to `table` is `None`.
-    :raises AttributeError: If a workbook is provided, and is a ReadOnlyWorksheet.
-    :raises ValueError: If there are no tables in the sheet.
-    :raises KeyError: If the provided table does not exist in the sheet.
+    Args:
+        path: Path to the Excel File. It can also be an openpyxl Workbook.
+        table: Name of a table, or list of tables in the sheet.
+        engine: DataFrame engine. Should be either pandas or polars.
+            Defaults to pandas
 
+    Raises:
+        AttributeError: If a workbook is provided, and is a ReadOnlyWorksheet.
+        ValueError: If there are no tables in the sheet.
+        KeyError: If the provided table does not exist in the sheet.
 
+    Returns:
+        A DataFrame, or a dictionary of DataFrames,
+            if there are multiple arguments for the `table` parameter,
+            or the argument to `table` is `None`.
     """  # noqa : E501
 
     try:
@@ -192,70 +247,99 @@ def xlsx_table(
             conda_channel="conda-forge",
             pip_install=True,
         )
+    # TODO: remove in version 1.0
+    if sheetname:
+        warnings.warn(
+            "The keyword argument "
+            "'sheetname' of 'xlsx_tables' is deprecated.",
+            DeprecationWarning,
+            stacklevel=find_stack_level(),
+        )
+    if engine not in {"pandas", "polars"}:
+        raise ValueError("engine should be one of pandas or polars.")
+    base_engine = pd
+    if engine == "polars":
+        try:
+            import polars as pl
+
+            base_engine = pl
+        except ImportError:
+            import_message(
+                submodule="polars",
+                package="polars",
+                conda_channel="conda-forge",
+                pip_install=True,
+            )
+
+    if table is not None:
+        check("table", table, [str, list, tuple])
+        if isinstance(table, (list, tuple)):
+            for num, entry in enumerate(table):
+                check(f"entry{num} in the table argument", entry, [str])
     if isinstance(path, Workbook):
-        ws = path[sheetname]
+        ws = path
     else:
         ws = load_workbook(
             filename=path, read_only=False, keep_links=False, data_only=True
         )
-        ws = ws[sheetname]
+    if ws.read_only:
+        raise ValueError("xlsx_table does not work in read only mode.")
 
-    try:
-        contents = ws.tables
-    except AttributeError as error:
-        raise AttributeError(
-            "Accessing the tables is not supported for ReadOnlyWorksheet"
-        ) from error
-
-    if not contents:
-        raise ValueError(f"There is no table in '{sheetname}' sheet.")
-
-    class TableArgs(NamedTuple):
+    def _create_dataframe_or_dictionary_from_table(
+        table_name_and_worksheet: tuple,
+    ):
         """
-        Named Tuple to easily index values
-        from the tables in the sheet.
+        Create DataFrame/dictionary if table exists in Workbook
         """
+        dictionary = {}
+        for table_name, worksheet in table_name_and_worksheet:
+            contents = worksheet.tables[table_name]
+            header_exist = contents.headerRowCount
+            coordinates = contents.ref
+            data = worksheet[coordinates]
+            if header_exist:
+                header, *data = data
+                header = [cell.value for cell in header]
+            else:
+                header = [f"C{num}" for num in range(len(data[0]))]
+            data = zip(*data)
+            data = ([entry.value for entry in cell] for cell in data)
+            data = dict(zip(header, data))
+            dictionary[table_name] = base_engine.DataFrame(data)
+        return dictionary
 
-        table_name: str
-        ref: str
-        headerRowCount: int
-
-    if isinstance(table, str):
-        table = [table]
-    if table is not None:
-        check("table", table, [str, list, tuple])
-        try:
-            data = []
-            for key in table:
-                outcome = TableArgs(
-                    key, contents[key].ref, contents[key].headerRowCount
-                )
-                data.append(outcome)
-        except KeyError as error:
-            raise KeyError(
-                f"Table {error} is not in the '{sheetname}' sheet."
-            ) from error
+    worksheets = [worksheet for worksheet in ws if worksheet.tables.items()]
+    if not any(worksheets):
+        raise ValueError("There are no tables in the Workbook.")
+    table_is_a_string = False
+    if table:
+        if isinstance(table, str):
+            table_is_a_string = True
+            table = [table]
+        table_names = (
+            entry for worksheet in worksheets for entry in worksheet.tables
+        )
+        missing = set(table).difference(table_names)
+        if missing:
+            raise KeyError(f"Tables {*missing,} do not exist in the Workbook.")
+        tables = [
+            (entry, worksheet)
+            for worksheet in worksheets
+            for entry in worksheet.tables
+            if entry in table
+        ]
     else:
-        data = (
-            TableArgs(key, contents[key].ref, contents[key].headerRowCount)
-            for key in contents
-        )
-
-    frame = {}
-    for table_arg in data:
-        content = [[cell.value for cell in row] for row in ws[table_arg.ref]]
-
-        if table_arg.headerRowCount:
-            header, *content = content
-        else:
-            header = [f"C{num}" for num in range(len(content[0]))]
-        frame[table_arg.table_name] = pd.DataFrame(
-            content, columns=header, copy=False
-        )
-
-    if len(frame) == 1:
-        _, frame = frame.popitem()
-    return frame
+        tables = [
+            (entry, worksheet)
+            for worksheet in worksheets
+            for entry in worksheet.tables
+        ]
+    data = _create_dataframe_or_dictionary_from_table(
+        table_name_and_worksheet=tables
+    )
+    if table_is_a_string:
+        return data[table[0]]
+    return data
 
 
 def xlsx_cells(
@@ -271,29 +355,32 @@ def xlsx_cells(
     border: bool = False,
     protection: bool = False,
     comment: bool = False,
-    **kwargs,
-) -> Union[dict, pd.DataFrame]:
-    """
-    Imports data from spreadsheet without coercing it into a rectangle.
+    engine: str = "pandas",
+    **kwargs: Any,
+) -> Mapping:
+    """Imports data from spreadsheet without coercing it into a rectangle.
+
     Each cell is represented by a row in a dataframe, and includes the
     cell's coordinates, the value, row and column position.
     The cell formatting (fill, font, border, etc) can also be accessed;
     usually this is returned as a dictionary in the cell, and the specific
-    cell format attribute can be accessed using `pd.Series.str.get`.
+    cell format attribute can be accessed using `pd.Series.str.get`
+    or `pl.struct.field` if it is a polars DataFrame.
 
     Inspiration for this comes from R's [tidyxl][link] package.
     [link]: https://nacnudus.github.io/tidyxl/reference/tidyxl.html
 
-    Example:
-
+    Examples:
         >>> import pandas as pd
+        >>> import polars as pl
         >>> from janitor import xlsx_cells
         >>> pd.set_option("display.max_columns", None)
         >>> pd.set_option("display.expand_frame_repr", False)
         >>> pd.set_option("max_colwidth", None)
         >>> filename = "../pyjanitor/tests/test_data/worked-examples.xlsx"
 
-        # Each cell is returned as a row:
+        Each cell is returned as a row:
+
         >>> xlsx_cells(filename, sheetnames="highlights")
             value internal_value coordinate  row  column data_type  is_date number_format
         0     Age            Age         A1    1       1         s    False       General
@@ -305,8 +392,9 @@ def xlsx_cells(
         6       5              5         A4    4       1         n    False       General
         7       6              6         B4    4       2         n    False       General
 
-        # Access cell formatting such as fill :
-        >>> out=xlsx_cells(filename, sheetnames="highlights", fill=True).select_columns("value", "fill")
+        Access cell formatting such as fill:
+
+        >>> out=xlsx_cells(filename, sheetnames="highlights", fill=True).select("value", "fill", axis='columns')
         >>> out
             value                                                                                                                                              fill
         0     Age     {'patternType': None, 'fgColor': {'rgb': '00000000', 'type': 'rgb', 'tint': 0.0}, 'bgColor': {'rgb': '00000000', 'type': 'rgb', 'tint': 0.0}}
@@ -318,7 +406,8 @@ def xlsx_cells(
         6       5     {'patternType': None, 'fgColor': {'rgb': '00000000', 'type': 'rgb', 'tint': 0.0}, 'bgColor': {'rgb': '00000000', 'type': 'rgb', 'tint': 0.0}}
         7       6     {'patternType': None, 'fgColor': {'rgb': '00000000', 'type': 'rgb', 'tint': 0.0}, 'bgColor': {'rgb': '00000000', 'type': 'rgb', 'tint': 0.0}}
 
-        # specific cell attributes can be accessed by using Pandas' series.str.get :
+        Specific cell attributes can be accessed by using Pandas' `series.str.get`:
+
         >>> out.fill.str.get("fgColor").str.get("rgb")
         0    00000000
         1    00000000
@@ -330,44 +419,84 @@ def xlsx_cells(
         7    00000000
         Name: fill, dtype: object
 
-    :param path: Path to the Excel File. It can also be an openpyxl Workbook.
-    :param sheetnames: Names of the sheets from which the cells are to be extracted.
-        If `None`, all the sheets in the file are extracted;
-        if it is a string, or list or tuple, only the specified sheets are extracted.
-    :param start_point: start coordinates of the Excel sheet. This is useful
-        if the user is only interested in a subsection of the sheet.
-        If start_point is provided, end_point must be provided as well.
-    :param end_point: end coordinates of the Excel sheet. This is useful
-        if the user is only interested in a subsection of the sheet.
-        If end_point is provided, start_point must be provided as well.
-    :param read_only: Determines if the entire file is loaded in memory,
-        or streamed. For memory efficiency, read_only should be set to `True`.
-        Some cell properties like `comment`, can only be accessed by
-        setting `read_only` to `False`.
-    :param include_blank_cells: Determines if cells without a value should be included.
-    :param fill: If `True`, return fill properties of the cell.
-        It is usually returned as a dictionary.
-    :param font: If `True`, return font properties of the cell.
-        It is usually returned as a dictionary.
-    :param alignment: If `True`, return alignment properties of the cell.
-        It is usually returned as a dictionary.
-    :param border: If `True`, return border properties of the cell.
-        It is usually returned as a dictionary.
-    :param protection: If `True`, return protection properties of the cell.
-        It is usually returned as a dictionary.
-    :param comment: If `True`, return comment properties of the cell.
-        It is usually returned as a dictionary.
-    :param kwargs: Any other attributes of the cell, that can be accessed from openpyxl.
-    :raises ValueError: If kwargs is provided, and one of the keys is a default column.
-    :raises AttributeError: If kwargs is provided and any of the keys
-        is not a openpyxl cell attribute.
-    :returns: A pandas DataFrame, or a dictionary of DataFrames.
+        Access cell formatting in a polars DataFrame:
+
+        >>> out = xlsx_cells(filename, sheetnames="highlights", engine='polars', fill=True).get_column('fill')
+        >>> out
+        shape: (8,)
+        Series: 'fill' [struct[3]]
+        [
+           {null,{"00000000","rgb",0.0},{"00000000","rgb",0.0}}
+           {null,{"00000000","rgb",0.0},{"00000000","rgb",0.0}}
+           {null,{"00000000","rgb",0.0},{"00000000","rgb",0.0}}
+           {null,{"00000000","rgb",0.0},{"00000000","rgb",0.0}}
+           {"solid",{"FFFFFF00","rgb",0.0},{"FFFFFF00","rgb",0.0}}
+           {"solid",{"FFFFFF00","rgb",0.0},{"FFFFFF00","rgb",0.0}}
+           {null,{"00000000","rgb",0.0},{"00000000","rgb",0.0}}
+           {null,{"00000000","rgb",0.0},{"00000000","rgb",0.0}}
+        ]
+
+        Specific cell attributes can be acessed via Polars' struct:
+
+        >>> out.struct.field('fgColor').struct.field('rgb')
+        shape: (8,)
+        Series: 'rgb' [str]
+        [
+           "00000000"
+           "00000000"
+           "00000000"
+           "00000000"
+           "FFFFFF00"
+           "FFFFFF00"
+           "00000000"
+           "00000000"
+        ]
+
+
+    Args:
+        path: Path to the Excel File. It can also be an openpyxl Workbook.
+        sheetnames: Names of the sheets from which the cells are to be extracted.
+            If `None`, all the sheets in the file are extracted;
+            if it is a string, or list or tuple, only the specified sheets are extracted.
+        start_point: Start coordinates of the Excel sheet. This is useful
+            if the user is only interested in a subsection of the sheet.
+            If `start_point` is provided, `end_point` must be provided as well.
+        end_point: End coordinates of the Excel sheet. This is useful
+            if the user is only interested in a subsection of the sheet.
+            If `end_point` is provided, `start_point` must be provided as well.
+        read_only: Determines if the entire file is loaded in memory,
+            or streamed. For memory efficiency, read_only should be set to `True`.
+            Some cell properties like `comment`, can only be accessed by
+            setting `read_only` to `False`.
+        include_blank_cells: Determines if cells without a value should be included.
+        fill: If `True`, return fill properties of the cell.
+            It is usually returned as a dictionary.
+        font: If `True`, return font properties of the cell.
+            It is usually returned as a dictionary.
+        alignment: If `True`, return alignment properties of the cell.
+            It is usually returned as a dictionary.
+        border: If `True`, return border properties of the cell.
+            It is usually returned as a dictionary.
+        protection: If `True`, return protection properties of the cell.
+            It is usually returned as a dictionary.
+        comment: If `True`, return comment properties of the cell.
+            It is usually returned as a dictionary.
+        engine: DataFrame engine. Should be either pandas or polars.
+        **kwargs: Any other attributes of the cell, that can be accessed from openpyxl.
+
+    Raises:
+        ValueError: If kwargs is provided, and one of the keys is a default column.
+        AttributeError: If kwargs is provided and any of the keys
+            is not a openpyxl cell attribute.
+
+    Returns:
+        A DataFrame, or a dictionary of DataFrames.
     """  # noqa : E501
 
     try:
         from openpyxl import load_workbook
-        from openpyxl.cell.read_only import ReadOnlyCell
         from openpyxl.cell.cell import Cell
+        from openpyxl.cell.read_only import ReadOnlyCell
         from openpyxl.workbook.workbook import Workbook
     except ImportError:
         import_message(
@@ -389,6 +518,21 @@ def xlsx_cells(
         path = load_workbook(
             filename=path, read_only=read_only, keep_links=False
         )
+    if engine not in {"pandas", "polars"}:
+        raise ValueError("engine should be one of pandas or polars.")
+    base_engine = pd
+    if engine == "polars":
+        try:
+            import polars as pl
+
+            base_engine = pl
+        except ImportError:
+            import_message(
+                submodule="polars",
+                package="polars",
+                conda_channel="conda-forge",
+                pip_install=True,
+            )
     # start_point and end_point applies if the user is interested in
     # only a subset of the Excel File and knows the coordinates
     if start_point or end_point:
@@ -460,6 +604,7 @@ def xlsx_cells(
             start_point,
             end_point,
             include_blank_cells,
+            base_engine=base_engine,
         )
         for sheetname in sheetnames
     }
@@ -479,19 +624,23 @@ def _xlsx_cells(
     start_point: Union[str, int],
     end_point: Union[str, int],
     include_blank_cells: bool,
+    base_engine,
 ):
     """
     Function to process a single sheet. Returns a DataFrame.
 
-    :param wb: Openpyxl Workbook.
-    :param defaults: Sequence of default cell attributes.
-    :param parameters: Dictionary of cell attributes to be retrieved.
-        that will always be returned as columns.
-    :param start_point: start coordinates of the Excel sheet.
-    :param end_point: end coordinates of the Excel sheet.
-    :param include_blank_cells: Determines if empty cells should be included.
-    :param path_is_workbook: True/False.
-    :returns : A pandas DataFrame.
+    Args:
+        wb: Openpyxl Workbook.
+        defaults: Sequence of default cell attributes.
+        parameters: Dictionary of cell attributes to be retrieved.
+            that will always be returned as columns.
+        start_point: start coordinates of the Excel sheet.
+        end_point: end coordinates of the Excel sheet.
+        include_blank_cells: Determines if empty cells should be included.
+        path_is_workbook: True/False.
+
+    Returns:
+        A DataFrame.
     """
 
     if start_point:
@@ -503,15 +652,23 @@ def _xlsx_cells(
         if (cell.value is None) and (not include_blank_cells):
             continue
         for value in defaults:
-            frame[value].append(getattr(cell, value, None))
+            outcome = getattr(cell, value, None)
+            if value.startswith("is_"):
+                pass
+            elif outcome is not None:
+                outcome = str(outcome)
+            frame[value].append(outcome)
         for parent, boolean_value in parameters.items():
             check(f"The value for {parent}", boolean_value, [bool])
             if not boolean_value:
                 continue
             boolean_value = _object_to_dict(getattr(cell, parent, None))
+            if isinstance(boolean_value, dict) or (boolean_value is None):
+                pass
+            else:
+                boolean_value = str(boolean_value)
             frame[parent].append(boolean_value)
-
-    return pd.DataFrame(frame, copy=False)
+    return base_engine.DataFrame(frame)
 
 
 def _object_to_dict(obj):
@@ -519,10 +676,13 @@ def _object_to_dict(obj):
     Recursively get the attributes
     of an object as a dictionary.
 
-    :param obj: Object whose attributes are to be extracted.
-    :returns: A dictionary or the object.
+    Args:
+        obj: Object whose attributes are to be extracted.
+
+    Returns:
+        A dictionary or the object.
     """
-    # https://stackoverflow.com/a/71366813/7175713
+    # https://stackoverflow.com/a/71366813
     data = {}
     if getattr(obj, "__dict__", None):
         for key, value in obj.__dict__.items():
