@@ -1,30 +1,24 @@
-"""Miscellaneous mathematical operators.
-
-Lazy loading used here to speed up imports.
-"""
+"""Miscellaneous mathematical operators."""
 
 import warnings
-from typing import Tuple
+from typing import TYPE_CHECKING, Tuple
 
+import pandas_flavor as pf
 
-import lazy_loader as lazy
-
-scipy_special = lazy.load("scipy.special")
-ss = lazy.load("scipy.stats")
-pf = lazy.load("pandas_flavor")
-pd = lazy.load("pandas")
-np = lazy.load("numpy")
-pdtypes = lazy.load("pandas.api.types")
+if TYPE_CHECKING:
+    from numpy import ndarray
+    from pandas import Series
 
 
 @pf.register_series_method
-def log(s: pd.Series, error: str = "warn") -> pd.Series:
+def log(s: "Series", error: str = "warn") -> "Series":
     """
     Take natural logarithm of the Series.
 
     Each value in the series should be positive. Use `error` to control the
     behavior if there are nonpositive entries in the series.
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> s = pd.Series([0, 1, 3], name="numbers")
@@ -34,15 +28,22 @@ def log(s: pd.Series, error: str = "warn") -> pd.Series:
         2    1.098612
         Name: numbers, dtype: float64
 
-    :param s: Input Series.
-    :param error: Determines behavior when taking the log of nonpositive
-        entries. If `'warn'` then a `RuntimeWarning` is thrown. If `'raise'`,
-        then a `RuntimeError` is thrown. Otherwise, nothing is thrown and
-        log of nonpositive values is `np.nan`; defaults to `'warn'`.
-    :raises RuntimeError: Raised when there are nonpositive values in the
-        Series and `error='raise'`.
-    :return: Transformed Series.
+    Args:
+        s: Input Series.
+        error: Determines behavior when taking the log of nonpositive
+            entries. If `'warn'` then a `RuntimeWarning` is thrown. If
+            `'raise'`, then a `RuntimeError` is thrown. Otherwise, nothing
+            is thrown and log of nonpositive values is `np.nan`.
+
+    Raises:
+        RuntimeError: Raised when there are nonpositive values in the
+            Series and `error='raise'`.
+
+    Returns:
+        Transformed Series.
     """
+    import numpy as np
+
     s = s.copy()
     nonpositive = s <= 0
     if (nonpositive).any():
@@ -58,10 +59,10 @@ def log(s: pd.Series, error: str = "warn") -> pd.Series:
 
 
 @pf.register_series_method
-def exp(s: pd.Series) -> pd.Series:
-    """
-    Take the exponential transform of the series.
+def exp(s: "Series") -> "Series":
+    """Take the exponential transform of the series.
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> s = pd.Series([0, 1, 3], name="numbers")
@@ -71,21 +72,28 @@ def exp(s: pd.Series) -> pd.Series:
         2    20.085537
         Name: numbers, dtype: float64
 
-    :param s: Input Series.
-    :return: Transformed Series.
+    Args:
+        s: Input Series.
+
+    Returns:
+        Transformed Series.
     """
+    import numpy as np
+
     return np.exp(s)
 
 
 @pf.register_series_method
-def sigmoid(s: pd.Series) -> pd.Series:
-    """
-    Take the sigmoid transform of the series where:
+def sigmoid(s: "Series") -> "Series":
+    """Take the sigmoid transform of the series.
+
+    The sigmoid function is defined:
 
     ```python
     sigmoid(x) = 1 / (1 + exp(-x))
     ```
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> s = pd.Series([-1, 0, 4], name="numbers")
@@ -95,16 +103,20 @@ def sigmoid(s: pd.Series) -> pd.Series:
         2    0.982014
         Name: numbers, dtype: float64
 
-    :param s: Input Series.
-    :return: Transformed Series.
+    Args:
+        s: Input Series.
+
+    Returns:
+        Transformed Series.
     """
-    return scipy_special.expit(s)
+    import scipy
+
+    return scipy.special.expit(s)
 
 
 @pf.register_series_method
-def softmax(s: pd.Series) -> pd.Series:
-    """
-    Take the softmax transform of the series.
+def softmax(s: "Series") -> "Series":
+    """Take the softmax transform of the series.
 
     The softmax function transforms each element of a collection by
     computing the exponential of each element divided by the sum of the
@@ -116,6 +128,7 @@ def softmax(s: pd.Series) -> pd.Series:
     softmax(x) = exp(x)/sum(exp(x))
     ```
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> s = pd.Series([0, 1, 3], name="numbers")
@@ -125,17 +138,23 @@ def softmax(s: pd.Series) -> pd.Series:
         2    0.843795
         Name: numbers, dtype: float64
 
-    :param s: Input Series.
-    :return: Transformed Series.
-    """
+    Args:
+        s: Input Series.
 
-    return pd.Series(scipy_special.softmax(s), index=s.index, name=s.name)
+    Returns:
+        Transformed Series.
+    """
+    import pandas as pd
+    import scipy
+
+    return pd.Series(scipy.special.softmax(s), index=s.index, name=s.name)
 
 
 @pf.register_series_method
-def logit(s: pd.Series, error: str = "warn") -> pd.Series:
-    """
-    Take logit transform of the Series where:
+def logit(s: "Series", error: str = "warn") -> "Series":
+    """Take logit transform of the Series.
+
+    The logit transform is defined:
 
     ```python
     logit(p) = log(p/(1-p))
@@ -144,6 +163,7 @@ def logit(s: pd.Series, error: str = "warn") -> pd.Series:
     Each value in the series should be between 0 and 1. Use `error` to
     control the behavior if any series entries are outside of (0, 1).
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> s = pd.Series([0.1, 0.5, 0.9], name="numbers")
@@ -153,14 +173,22 @@ def logit(s: pd.Series, error: str = "warn") -> pd.Series:
         2    2.197225
         Name: numbers, dtype: float64
 
-    :param s: Input Series.
-    :param error: Determines behavior when `s` is outside of `(0, 1)`.
-        If `'warn'` then a `RuntimeWarning` is thrown. If `'raise'`, then a
-        `RuntimeError` is thrown. Otherwise, nothing is thrown and `np.nan`
-        is returned for the problematic entries; defaults to `'warn'`.
-    :return: Transformed Series.
-    :raises RuntimeError: if `error` is set to `'raise'`.
+    Args:
+        s: Input Series.
+        error: Determines behavior when `s` is outside of `(0, 1)`.
+            If `'warn'` then a `RuntimeWarning` is thrown. If `'raise'`, then a
+            `RuntimeError` is thrown. Otherwise, nothing is thrown and `np.nan`
+            is returned for the problematic entries; defaults to `'warn'`.
+
+    Raises:
+        RuntimeError: If `error` is set to `'raise'`.
+
+    Returns:
+        Transformed Series.
     """
+    import numpy as np
+    import scipy
+
     s = s.copy()
     outside_support = (s <= 0) | (s >= 1)
     if (outside_support).any():
@@ -172,14 +200,14 @@ def logit(s: pd.Series, error: str = "warn") -> pd.Series:
         else:
             pass
     s[outside_support] = np.nan
-    return scipy_special.logit(s)
+    return scipy.special.logit(s)
 
 
 @pf.register_series_method
-def normal_cdf(s: pd.Series) -> pd.Series:
-    """
-    Transforms the Series via the CDF of the Normal distribution.
+def normal_cdf(s: "Series") -> "Series":
+    """Transforms the Series via the CDF of the Normal distribution.
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> s = pd.Series([-1, 0, 3], name="numbers")
@@ -189,20 +217,26 @@ def normal_cdf(s: pd.Series) -> pd.Series:
         2    0.998650
         dtype: float64
 
-    :param s: Input Series.
-    :return: Transformed Series.
+    Args:
+        s: Input Series.
+
+    Returns:
+        Transformed Series.
     """
-    return pd.Series(ss.norm.cdf(s), index=s.index)
+    import pandas as pd
+    import scipy
+
+    return pd.Series(scipy.stats.norm.cdf(s), index=s.index)
 
 
 @pf.register_series_method
-def probit(s: pd.Series, error: str = "warn") -> pd.Series:
-    """
-    Transforms the Series via the inverse CDF of the Normal distribution.
+def probit(s: "Series", error: str = "warn") -> "Series":
+    """Transforms the Series via the inverse CDF of the Normal distribution.
 
     Each value in the series should be between 0 and 1. Use `error` to
     control the behavior if any series entries are outside of (0, 1).
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> s = pd.Series([0.1, 0.5, 0.8], name="numbers")
@@ -212,15 +246,24 @@ def probit(s: pd.Series, error: str = "warn") -> pd.Series:
         2    0.841621
         dtype: float64
 
-    :param s: Input Series.
-    :param error: Determines behavior when `s` is outside of `(0, 1)`.
-        If `'warn'` then a `RuntimeWarning` is thrown. If `'raise'`, then
-        a `RuntimeError` is thrown. Otherwise, nothing is thrown and `np.nan`
-        is returned for the problematic entries; defaults to `'warn'`.
-    :raises RuntimeError: Raised when there are problematic values
-        in the Series and `error='raise'`.
-    :return: Transformed Series
+    Args:
+        s: Input Series.
+        error: Determines behavior when `s` is outside of `(0, 1)`.
+            If `'warn'` then a `RuntimeWarning` is thrown. If `'raise'`, then
+            a `RuntimeError` is thrown. Otherwise, nothing is thrown and
+            `np.nan` is returned for the problematic entries.
+
+    Raises:
+        RuntimeError: When there are problematic values
+            in the Series and `error='raise'`.
+
+    Returns:
+        Transformed Series
     """
+    import numpy as np
+    import pandas as pd
+    import scipy
+
     s = s.copy()
     outside_support = (s <= 0) | (s >= 1)
     if (outside_support).any():
@@ -233,23 +276,25 @@ def probit(s: pd.Series, error: str = "warn") -> pd.Series:
             pass
     s[outside_support] = np.nan
     with np.errstate(all="ignore"):
-        out = pd.Series(ss.norm.ppf(s), index=s.index)
+        out = pd.Series(scipy.stats.norm.ppf(s), index=s.index)
     return out
 
 
 @pf.register_series_method
 def z_score(
-    s: pd.Series,
+    s: "Series",
     moments_dict: dict = None,
     keys: Tuple[str, str] = ("mean", "std"),
-) -> pd.Series:
-    """
-    Transforms the Series into z-scores where:
+) -> "Series":
+    """Transforms the Series into z-scores.
+
+    The z-score is defined:
 
     ```python
     z = (s - s.mean()) / s.std()
     ```
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> s = pd.Series([0, 1, 3], name="numbers")
@@ -259,14 +304,17 @@ def z_score(
         2    1.091089
         Name: numbers, dtype: float64
 
-    :param s: Input Series.
-    :param moments_dict: If not `None`, then the mean and standard
-        deviation used to compute the z-score transformation is
-        saved as entries in `moments_dict` with keys determined by
-        the `keys` argument; defaults to `None`.
-    :param keys: Determines the keys saved in `moments_dict`
-        if moments are saved; defaults to (`'mean'`, `'std'`).
-    :return: Transformed Series.
+    Args:
+        s: Input Series.
+        moments_dict: If not `None`, then the mean and standard
+            deviation used to compute the z-score transformation is
+            saved as entries in `moments_dict` with keys determined by
+            the `keys` argument; defaults to `None`.
+        keys: Determines the keys saved in `moments_dict`
+            if moments are saved; defaults to (`'mean'`, `'std'`).
+
+    Returns:
+        Transformed Series.
     """
     mean = s.mean()
     std = s.std()
@@ -279,21 +327,8 @@ def z_score(
 
 
 @pf.register_series_method
-def ecdf(s: pd.Series) -> Tuple[np.ndarray, np.ndarray]:
-    """
-    Return cumulative distribution of values in a series.
-
-    Intended to be used with the following pattern:
-
-    ```python
-    df = pd.DataFrame(...)
-
-    # Obtain ECDF values to be plotted
-    x, y = df["column_name"].ecdf()
-
-    # Plot ECDF values
-    plt.scatter(x, y)
-    ```
+def ecdf(s: "Series") -> Tuple["ndarray", "ndarray"]:
+    """Return cumulative distribution of values in a series.
 
     Null values must be dropped from the series,
     otherwise a `ValueError` is raised.
@@ -301,6 +336,7 @@ def ecdf(s: pd.Series) -> Tuple[np.ndarray, np.ndarray]:
     Also, if the `dtype` of the series is not numeric,
     a `TypeError` is raised.
 
+    Examples:
         >>> import pandas as pd
         >>> import janitor
         >>> s = pd.Series([0, 4, 0, 1, 2, 1, 1, 3])
@@ -310,13 +346,25 @@ def ecdf(s: pd.Series) -> Tuple[np.ndarray, np.ndarray]:
         >>> y  # doctest: +SKIP
         array([0.125, 0.25 , 0.375, 0.5  , 0.625, 0.75 , 0.875, 1.   ])
 
-    :param s: A pandas series. `dtype` should be numeric.
-    :returns: `(x, y)`.
-        `x`: sorted array of values.
-        `y`: cumulative fraction of data points with value `x` or lower.
-    :raises TypeError: if series is not numeric.
-    :raises ValueError: if series contains nulls.
+        You can then plot the ECDF values, for example:
+
+        >>> from matplotlib import pyplot as plt
+        >>> plt.scatter(x, y)  # doctest: +SKIP
+
+    Args:
+        s: A pandas series. `dtype` should be numeric.
+
+    Raises:
+        TypeError: If series is not numeric.
+        ValueError: If series contains nulls.
+
+    Returns:
+        x: Sorted array of values.
+        y: Cumulative fraction of data points with value `x` or lower.
     """
+    import numpy as np
+    import pandas.api.types as pdtypes
+
     if not pdtypes.is_numeric_dtype(s):
         raise TypeError(f"series {s.name} must be numeric!")
     if not s.isna().sum() == 0:
