@@ -1,19 +1,18 @@
-"""
-General purpose data cleaning functions for pyspark.
-"""
+"""General purpose data cleaning functions for pyspark."""
 
 import re
 from typing import Union
 
 from janitor import utils as janitor_utils
-from . import backend
-from janitor.functions.clean_names import (
+from janitor.functions.utils import (
     _change_case,
     _normalize_1,
     _remove_special,
     _strip_underscores_func,
 )
 
+from . import backend
+
 try:
     from pyspark.sql import DataFrame
 except ImportError:
@@ -32,48 +31,41 @@ def clean_names(
     remove_special: bool = False,
     strip_underscores: str = None,
 ) -> DataFrame:
-    """
-    Clean column names for pyspark dataframe.
+    """Clean column names for pyspark dataframe.
 
     Takes all column names, converts them to lowercase, then replaces all
     spaces with underscores.
 
     This method does not mutate the original DataFrame.
 
-    Functional usage example:
+    Examples:
+        >>> from pyspark.sql import DataFrame
+        >>> import janitor.spark
+        >>> df = DataFrame(...).clean_names()  # doctest: +SKIP
 
-    .. code-block:: python
-
-        df = clean_names(df)
-
-    Method chaining example:
-
-    .. code-block:: python
-
-        from pyspark.sql import DataFrame
-        import janitor.spark
-        df = DataFrame(...).clean_names()
-
-    :Example of transformation:
-
-    .. code-block:: python
+        Example of transformation:
 
+        ```
         Columns before: First Name, Last Name, Employee Status, Subject
         Columns after: first_name, last_name, employee_status, subject
+        ```
 
-    :param df: Spark DataFrame object.
-    :param strip_underscores: (optional) Removes the outer underscores from all
-        column names. Default None keeps outer underscores. Values can be
-        either 'left', 'right' or 'both' or the respective shorthand 'l', 'r'
-        and True.
-    :param case_type: (optional) Whether to make columns lower or uppercase.
-        Current case may be preserved with 'preserve',
-        while snake case conversion (from CamelCase or camelCase only)
-        can be turned on using "snake".
-        Default 'lower' makes all characters lowercase.
-    :param remove_special: (optional) Remove special characters from columns.
-        Only letters, numbers and underscores are preserved.
-    :returns: A Spark DataFrame.
+    Args:
+        df: Spark DataFrame object.
+        strip_underscores: Removes the outer underscores from all
+            column names. Default None keeps outer underscores. Values can be
+            either 'left', 'right' or 'both' or the respective shorthand 'l',
+            'r' and True.
+        case_type: Whether to make columns lower or uppercase.
+            Current case may be preserved with 'preserve',
+            while snake case conversion (from CamelCase or camelCase only)
+            can be turned on using "snake".
+            Default 'lower' makes all characters lowercase.
+        remove_special: Remove special characters from columns.
+            Only letters, numbers and underscores are preserved.
+
+    Returns:
+        A Spark DataFrame.
     """
 
     cols = df.columns
@@ -103,53 +95,51 @@ def update_where(
     target_column_name: str,
     target_val: Union[str, int, float],
 ) -> DataFrame:
-    """
-    Add multiple conditions to update a column in the dataframe.
+    """Add multiple conditions to update a column in the dataframe.
 
     This method does not mutate the original DataFrame.
 
-    Example usage:
+    Examples:
 
-    .. code-block:: python
+        >>> import pandas as pd
+        >>> from pyspark.sql import SparkSession
+        >>> spark = SparkSession.builder.getOrCreate()
+        >>> import janitor.spark
+        >>> data = {
+        ...     "a": [1, 2, 3, 4],
+        ...     "b": [5, 6, 7, 8],
+        ...     "c": [0, 0, 0, 0]
+        ... }
+        >>> df = spark.createDataFrame(pd.DataFrame(data))
+        >>> df = (
+        ...     df
+        ...     .update_where(
+        ...         conditions="a > 2 AND b < 8",
+        ...         target_column_name='c',
+        ...         target_val=10
+        ...     )
+        ... )  # doctest: +SKIP
+        >>> df.show()  # doctest: +SKIP
+        +---+---+---+
+        |  a|  b|  c|
+        +---+---+---+
+        |  1|  5|  0|
+        |  2|  6|  0|
+        |  3|  7| 10|
+        |  4|  8|  0|
+        +---+---+---+
 
-        import pandas as pd
-        from pyspark.sql import SparkSession
-        import janitor.spark
+    Args:
+        df: Spark DataFrame object.
+        conditions: Spark SQL string condition used to update a target
+            column and target value
+        target_column_name: Column to be updated. If column does not exist
+            in dataframe, a new column will be created; note that entries that
+            do not get set in the new column will be null.
+        target_val: Value to be updated
 
-        spark = SparkSession.builder.getOrCreate()
-
-        data = {
-            "a": [1, 2, 3, 4],
-            "b": [5, 6, 7, 8],
-            "c": [0, 0, 0, 0]
-        }
-        df = spark.createDataFrame(pd.DataFrame(data))
-        df = (
-            df
-            .update_where(
-                conditions="a > 2 AND b < 8",
-                target_column_name='c',
-                target_val=10
-            )
-        )
-        df.show()
-        # +---+---+---+
-        # |  a|  b|  c|
-        # +---+---+---+
-        # |  1|  5|  0|
-        # |  2|  6|  0|
-        # |  3|  7| 10|
-        # |  4|  8|  0|
-        # +---+---+---+
-
-    :param df: Spark DataFrame object.
-    :param conditions: Spark SQL string condition used to update a target
-        column and target value
-    :param target_column_name: Column to be updated. If column does not exist
-        in dataframe, a new column will be created; note that entries that do
-        not get set in the new column will be null.
-    :param target_val: Value to be updated
-    :returns: An updated spark DataFrame.
+    Returns:
+        An updated spark DataFrame.
     """
 
     # String without quotes are treated as column name
